import 'dart:async';

import 'package:flutter/services.dart';
import 'package:flutter/widgets.dart';

class AdaptiveDimensions {
  BuildContext _buildContext;
  double _referenceWidth;
  double _referenceHeight;
  MediaQueryData _mediaQuery;

  double _widthScaleFactor;
  double _heightScaleFactor;
  double _textScaleFactor;

  AdaptiveDimensions(
      this._buildContext, this._referenceWidth, this._referenceHeight) {
    _mediaQuery = MediaQuery.of(_buildContext);
    _widthScaleFactor = _mediaQuery.size.width / _referenceWidth;
    _heightScaleFactor = _mediaQuery.size.height / _referenceHeight;
    _textScaleFactor = _mediaQuery.textScaleFactor;
  }

  width(double width) => width * _widthScaleFactor;

  height(double height) => height * _heightScaleFactor;

  size(double fontSize, {bool scale = true}) =>
      scale ? width(fontSize) / _textScaleFactor : width(fontSize);

  top(double top) => top * _heightScaleFactor;

  bottom(double bottom) => bottom * _heightScaleFactor;

  left(double left) => left * _widthScaleFactor;

  right(double right) => right * _widthScaleFactor;
}
